@@ -25,7 +25,6 @@ class GeoMap:
         self.commit = "reverse Geocoder takes a latitude / longitude coordinate and returns the nearest town/city."
         self.df_geo_dict = None
         self.country = country
-        self.series_name = country
         self.html_name = os.path.abspath('geo.html')
         self.echarts_url = "https://echarts-maps.github.io/echarts-countries-js/"
         self.geo_dict = {}
@@ -61,13 +60,13 @@ class GeoMap:
         self.geo_dict = dict(df_geo.apply(lambda x:(x['admin1'],[x['lon'],x['lat']]),axis=1).values)
         return df_geo
 
-    def plot_geo_summary(self,_geo_data,series_name):
+    def plot_geo_summary(self,_geo_data,series_name=None):
         '''
         plot geo 经纬度聚类信息
         :param geo_data: geo对应的城市分布(Series)
         :return:
         '''
-        self.series_name = series_name
+        self.series_name = series_name if series_name else self.country
         geo_data = np.array(list(dict(_geo_data).items()))
         self.threshold_plot = np.percentile(_geo_data, 80)
         _geo = self.get_geo_base(geo_data)
