@@ -11,6 +11,7 @@ Desc:
 import sys
 import math
 
+# 进度条展示 progress_bar(1, 100)
 def progress_bar(portion, total):
     """
     total 总数据大小，portion 已经传送的数据大小
@@ -27,3 +28,17 @@ def progress_bar(portion, total):
     if portion >= total:
         sys.stdout.write('\n')
     return True
+
+
+if __name__ == '__main__':
+    # 进度条
+    portion = 0
+    total = 254820000
+    while True:
+        portion += 1024
+        sum = progress_bar(portion, total)
+        if sum:
+           break
+        print("ok")
+
+    ##
